@@ -16,6 +16,7 @@
 
 from __future__ import print_function
 
+
 import argparse
 try:
     import configparser
@@ -23,46 +24,46 @@ except ImportError:
     import ConfigParser as configparser
 import logging
 import os
-from os.path import expanduser
 import socket
 import sys
-from freezer import utils
+
 from distutils import spawn as distspawn
-
 from oslo_utils import encodeutils
-
-from freezer import winutils
 from tempfile import NamedTemporaryFile
 
-home = expanduser("~")
+from freezer import config
+from freezer import utils
+from freezer import winutils
+
+home = os.path.expanduser("~")
 
 DEFAULT_LVM_SNAPNAME = 'freezer_backup_snap'
 DEFAULT_LVM_SNAPSIZE = '1G'
 DEFAULT_LVM_DIRMOUNT = '/var/lib/freezer'
 
 DEFAULT_PARAMS = {
-    'os_identity_api_version': None, 'list_objects': False,
-    'get_object': False, 'lvm_auto_snap': False, 'lvm_volgroup': False,
+    'os_identity_api_version': None,
+    'lvm_auto_snap': False, 'lvm_volgroup': False,
     'exclude': False, 'sql_server_conf': False,
     'backup_name': False, 'quiet': False,
     'container': 'freezer_backups', 'no_incremental': False,
     'max_segment_size': 67108864, 'lvm_srcvol': False,
     'download_limit': None, 'hostname': False, 'remove_from_date': False,
     'restart_always_level': False, 'lvm_dirmount': DEFAULT_LVM_DIRMOUNT,
-    'dst_file': False, 'dereference_symlink': '',
+    'dereference_symlink': '',
     'restore_from_host': False, 'config': False, 'mysql_conf': False,
     'insecure': False, 'lvm_snapname': DEFAULT_LVM_SNAPNAME,
     'lvm_snapperm': 'ro', 'snapshot': False,
     'max_priority': False, 'max_level': False, 'path_to_backup': False,
     'encrypt_pass_file': False, 'volume': False, 'proxy': False,
     'cinder_vol_id': '', 'cindernative_vol_id': '',
-    'nova_inst_id': '', 'list_containers': False,
+    'nova_inst_id': '',
     'remove_older_than': None, 'restore_from_date': False,
     'upload_limit': None, 'always_level': False, 'version': False,
     'dry_run': False, 'lvm_snapsize': DEFAULT_LVM_SNAPSIZE,
-    'restore_abs_path': False, 'log_file': None,
-    'upload': True, 'mode': 'fs', 'action': 'backup',
-    'vssadmin': True, 'shadow': '', 'shadow_path': '',
+    'restore_abs_path': False, 'log_file': None, 'log_level': "info",
+    'mode': 'fs', 'action': 'backup',
+    'vssadmin': False, 'shadow': '', 'shadow_path': '',
     'windows_volume': '', 'command': None, 'metadata_out': False,
     'storage': 'swift', 'ssh_key': '', 'ssh_username': '', 'ssh_host': '',
     'ssh_port': 22, 'compression': 'gzip'
@@ -88,7 +89,7 @@ def enrich_defaults(config_path):
     return defaults
 
 
-def backup_arguments(args_dict={}):
+def backup_arguments():
     """
     Default arguments and command line options interface. The function return
     a name space called backup_args.
@@ -106,7 +107,11 @@ def backup_arguments(args_dict={}):
               "from command line provided take precedence."))
 
     args, remaining_argv = conf_parser.parse_known_args()
-    defaults = enrich_defaults(args.config)
+    defaults = DEFAULT_PARAMS.copy()
+    conf = None
+    if args.config:
+        conf = config.Config.parse(args.config)
+        defaults.update(conf.default)
 
     # Generate a new argparse istance and inherit options from config parse
     arg_parser = argparse.ArgumentParser(
@@ -141,22 +146,6 @@ def backup_arguments(args_dict={}):
         help="The Swift container (or path to local storage) "
              "used to upload files to",
         dest='container', default='freezer_backups')
-    arg_parser.add_argument(
-        '-L', '--list-containers', action='store_true',
-        help='''List the Swift containers on remote Object Storage Server''',
-        dest='list_containers', default=False)
-    arg_parser.add_argument(
-        '-l', '--list-objects', action='store_true',
-        help='''List the Swift objects stored in a container on remote Object\
-        Storage Server.''', dest='list_objects', default=False)
-    arg_parser.add_argument(
-        '-o', '--get-object', action='store',
-        help="The Object name you want to download on the local file system.",
-        dest='get_object', default=False)
-    arg_parser.add_argument(
-        '-d', '--dst-file', action='store',
-        help="The file name used to save the object on your local disk and\
-        upload file in swift", dest='dst_file', default=False)
     arg_parser.add_argument(
         '-s', '--snapshot', action='store_true',
         help=('Create a snapshot of the fs containing the resource to backup.'
@@ -282,6 +271,12 @@ def backup_arguments(args_dict={}):
                  'If that file is not writable, freezer tries to log'
                  'to ~/.freezer/freezer.log',
             dest='log_file', default=None)
+    arg_parser.add_argument(
+        '--log-level', action='store', dest="log_level",
+        default=DEFAULT_PARAMS['log_level'],
+        choices=['all', 'debug', 'info', 'warn', 'error', 'critical'],
+        help='Set logging level. Can be all, debug, info, warn,'
+             'error, critical. Default value - info')
     arg_parser.add_argument(
         '--exclude', action='store', help="Exclude files,\
         given as a PATTERN.Ex: --exclude '*.log' will exclude any file \
@@ -293,10 +288,6 @@ def backup_arguments(args_dict={}):
             "Follow hard and soft links and archive and dump the files they "
             " refer to. Default False."),
         dest='dereference_symlink', default='')
-    arg_parser.add_argument(
-        '-U', '--upload', action='store_true',
-        help="Upload to Swift the destination file passed to the -d option.\
-            Default upload the data", dest='upload', default=True)
     arg_parser.add_argument(
         '--encrypt-pass-file', action='store',
         help="Passing a private key to this option, allow you to encrypt the \
@@ -395,10 +386,10 @@ def backup_arguments(args_dict={}):
         instance = <db-instance>''',
         dest='sql_server_conf', default=False)
     arg_parser.add_argument(
-        '--vssadmin', action='store',
+        '--vssadmin', action='store_true',
         help='''Create a backup using a snapshot on windows
         using vssadmin. Options are: True and False, default is True''',
-        dest='vssadmin', default=True)
+        dest='vssadmin', default=False)
     arg_parser.add_argument(
         '--command', action='store',
         help='Command executed by exec action',
@@ -436,10 +427,6 @@ def backup_arguments(args_dict={}):
     arg_parser.set_defaults(**defaults)
     backup_args = arg_parser.parse_args()
 
-    # Intercept command line arguments if you are not using the CLIvss
-    if args_dict:
-        backup_args.__dict__.update(args_dict)
-
     # Set default working directory to ~/.freezer. If the directory
     # does not exists it is created
     work_dir = os.path.join(home, '.freezer')
@@ -455,16 +442,6 @@ def backup_arguments(args_dict={}):
             print(encodeutils.safe_decode(
                 '{}'.format(err_msg)), file=sys.stderr)
 
-    # The containers used by freezer to executed backups needs to have
-    # freezer_ prefix in the name. If the user provider container doesn't
-    # have the prefix, it is automatically added also to the container
-    # segments name. This is done to quickly identify the containers
-    # that contain freezer generated backups
-    if not backup_args.container.startswith('freezer_') and \
-            backup_args.storage == 'swift':
-        backup_args.container = 'freezer_{0}'.format(
-            backup_args.container)
-
     # If hostname is not set, hostname of the current node will be used
     if not backup_args.hostname:
         backup_args.__dict__['hostname'] = socket.gethostname()
@@ -476,6 +453,9 @@ def backup_arguments(args_dict={}):
 
     # MySQLdb object
     backup_args.__dict__['mysql_db_inst'] = ''
+    backup_args.__dict__['storages'] = None
+    if conf and conf.storages:
+        backup_args.__dict__['storages'] = conf.storages
 
     # Windows volume
     backup_args.__dict__['shadow'] = ''
@@ -486,11 +466,8 @@ def backup_arguments(args_dict={}):
             backup_args.__dict__['windows_volume'] = \
                 backup_args.path_to_backup[:3]
 
-        if backup_args.vssadmin == 'False' or backup_args.vssadmin == 'false':
-            backup_args.vssadmin = False
-
     # Freezer version
-    backup_args.__dict__['__version__'] = '1.1.3'
+    backup_args.__dict__['__version__'] = '1.2.0'
 
     # todo(enugaev) move it to new command line param backup_media
     backup_media = 'fs'
