@@ -17,22 +17,18 @@ Freezer Backup modes related functions
 """
 import logging
 import os
-from os.path import expanduser
 import time
 
-from freezer import utils
+from freezer import config
 from freezer import lvm
-from freezer.vss import vss_create_shadow_copy
-from freezer.vss import vss_delete_shadow_copy
-from freezer.winutils import start_sql_server
-from freezer.winutils import stop_sql_server
-from freezer.winutils import use_shadow
-from freezer.winutils import is_windows
+from freezer import utils
+from freezer import vss
+from freezer import winutils
 
-home = expanduser("~")
+home = os.path.expanduser("~")
 
 
-def backup_mode_sql_server(backup_opt_dict):
+def backup_mode_sql_server(backup_opt_dict, storage):
     """
     Execute a SQL Server DB backup. Currently only backups with shadow
     copy are supported. This mean, as soon as the shadow copy is created
@@ -41,35 +37,21 @@ def backup_mode_sql_server(backup_opt_dict):
     uploaded. A sql_server.conf_file is required for this operation.
     """
     with open(backup_opt_dict.sql_server_conf, 'r') as sql_conf_file_fd:
-        for line in sql_conf_file_fd:
-            line = line.strip().split('#', 1)[0]
-            if not line:
-                continue
-
-            key, value = line.split('=')
-            # remove white spaces
-            key = key.strip()
-            value = value.strip()
-
-            if key == 'instance':
-                db_instance = utils.dequote(value)
-                backup_opt_dict.sql_server_instance = db_instance
-                continue
-            else:
-                raise Exception('Please indicate a valid SQL Server instance')
-
+        parsed_config = config.ini_parse(sql_conf_file_fd.read())
+    sql_server_instance = parsed_config["instance"]
+    # Dirty hack - please remove any modification of backup_opt_dict
+    backup_opt_dict.sql_server_instance = sql_server_instance
     try:
-        stop_sql_server(backup_opt_dict.sql_server_instance)
-        backup(backup_opt_dict, backup_opt_dict.storage,
-               backup_opt_dict.engine)
+        winutils.stop_sql_server(sql_server_instance)
+        backup(backup_opt_dict, storage, backup_opt_dict.engine)
     finally:
         if not backup_opt_dict.vssadmin:
             # if vssadmin is false, wait until the backup is complete
             # to start sql server again
-            start_sql_server(backup_opt_dict.sql_server_instance)
+            winutils.start_sql_server(sql_server_instance)
 
 
-def backup_mode_mysql(backup_opt_dict):
+def backup_mode_mysql(backup_opt_dict, storage):
     """
     Execute a MySQL DB backup. currently only backup with lvm snapshots
     are supported. This mean, just before the lvm snap vol is created,
@@ -87,55 +69,25 @@ def backup_mode_mysql(backup_opt_dict):
 
     if not backup_opt_dict.mysql_conf:
         raise ValueError('MySQL: please provide a valid config file')
-    # Open the file provided in backup_args.mysql_conf and extract the
-    # db host, name, user, password and port.
-    db_user = db_host = db_pass = False
-    # Use the default mysql port if not provided
-    db_port = 3306
     with open(backup_opt_dict.mysql_conf, 'r') as mysql_file_fd:
-        for line in mysql_file_fd:
-            line = line.strip().split('#', 1)[0]
-            if not line:
-                continue
-
-            key, value = line.split('=')
-            # remove white spaces
-            key = key.strip()
-            value = value.strip()
-
-            if key == 'host':
-                db_host = utils.dequote(value)
-                continue
-
-            if key == 'user':
-                db_user = utils.dequote(value)
-                continue
-
-            if key == 'password':
-                db_pass = utils.dequote(value)
-                continue
-
-            if key == 'port':
-                db_port = utils.dequote(value)
-                try:
-                    db_port = int(db_port)
-                except ValueError:
-                    raise ValueError('[*] MySQL port should be integer')
-                continue
+        parsed_config = config.ini_parse(mysql_file_fd.read())
 
     # Initialize the DB object and connect to the db according to
     # the db mysql backup file config
     try:
         backup_opt_dict.mysql_db_inst = MySQLdb.connect(
-            host=db_host, port=db_port, user=db_user, passwd=db_pass)
+            host=parsed_config.get("host", False),
+            port=int(parsed_config.get("port", 3306)),
+            user=parsed_config.get("user", False),
+            passwd=parsed_config.get("password", False))
     except Exception as error:
         raise Exception('[*] MySQL: {0}'.format(error))
 
     # Execute backup
-    backup(backup_opt_dict, backup_opt_dict.storage, backup_opt_dict.engine)
+    backup(backup_opt_dict, storage, backup_opt_dict.engine)
 
 
-def backup_mode_mongo(backup_opt_dict):
+def backup_mode_mongo(backup_opt_dict, storage):
     """
     Execute the necessary tasks for file system backup mode
     """
@@ -156,8 +108,7 @@ def backup_mode_mongo(backup_opt_dict):
     mongo_primary = master_dict['primary']
 
     if mongo_me == mongo_primary:
-        backup(backup_opt_dict, backup_opt_dict.storage,
-               backup_opt_dict.engine)
+        backup(backup_opt_dict, storage, backup_opt_dict.engine)
     else:
         logging.warning('[*] localhost {0} is not Master/Primary,\
         exiting...'.format(local_hostname))
@@ -261,22 +212,22 @@ def snapshot_create(backup_opt_dict):
     :return: boolean value, True if snapshot has been taken, false otherwise
     """
 
-    if is_windows():
+    if winutils.is_windows():
         # vssadmin is to be deprecated in favor of the --snapshot flag
         if backup_opt_dict.snapshot:
             backup_opt_dict.vssadmin = True
         if backup_opt_dict.vssadmin:
             # Create a shadow copy.
             backup_opt_dict.shadow_path, backup_opt_dict.shadow = \
-                vss_create_shadow_copy(backup_opt_dict.windows_volume)
+                vss.vss_create_shadow_copy(backup_opt_dict.windows_volume)
 
-            backup_opt_dict.path_to_backup = use_shadow(
+            backup_opt_dict.path_to_backup = winutils.use_shadow(
                 backup_opt_dict.path_to_backup,
                 backup_opt_dict.windows_volume)
 
             # execute this after the snapshot creation
             if backup_opt_dict.mode == 'sqlserver':
-                start_sql_server(backup_opt_dict.sql_server_instance)
+                winutils.start_sql_server(backup_opt_dict.sql_server_instance)
 
             return True
         return False
@@ -287,9 +238,9 @@ def snapshot_create(backup_opt_dict):
 
 
 def snapshot_remove(backup_opt_dict, shadow, windows_volume):
-    if is_windows():
+    if winutils.is_windows():
         # Delete the shadow copy after the backup
-        vss_delete_shadow_copy(shadow, windows_volume)
+        vss.vss_delete_shadow_copy(shadow, windows_volume)
     else:
         # Unmount and remove lvm snapshot volume
         lvm.lvm_snap_remove(backup_opt_dict)
@@ -300,7 +251,7 @@ def backup(backup_opt_dict, storage, engine):
 
     :param backup_opt_dict:
     :param storage:
-    :type storage: freezer.storage.Storage
+    :type storage: freezer.storage.base.Storage
     :param engine: Backup Engine
     :type engine: freezer.engine.engine.BackupEngine
     :return:
